@@ -1,51 +1,51 @@
 #!/usr/bin/env python3
-# dominfo - print some information about a domain
+"""
+Print information about the domain DOMAIN
+"""
 
 import libvirt
-import sys
-import os
 import libxml2
-import pdb
+from argparse import ArgumentParser
+from typing import Any
 
-def usage():
-   print('Usage: %s DOMAIN' % sys.argv[0])
-   print('       Print information about the domain DOMAIN')
 
-def print_section(title):
+parser = ArgumentParser(description=__doc__)
+parser.add_argument("domain")
+args = parser.parse_args()
+
+
+def print_section(title: str) -> None:
     print("\n%s" % title)
     print("=" * 60)
 
-def print_entry(key, value):
+
+def print_entry(key: str, value: Any) -> None:
     print("%-10s %-10s" % (key, value))
 
-def print_xml(key, ctx, path):
+
+def print_xml(key: str, ctx, path: str) -> str:
     res = ctx.xpathEval(path)
     if res is None or len(res) == 0:
-        value="Unknown"
+        value = "Unknown"
     else:
         value = res[0].content
     print_entry(key, value)
     return value
 
-if len(sys.argv) != 2:
-    usage()
-    sys.exit(2)
-
-name = sys.argv[1]
 
 # Connect to libvirt
 try:
     conn = libvirt.openReadOnly(None)
 except libvirt.libvirtError:
     print('Failed to open connection to the hypervisor')
-    sys.exit(1)
+    exit(1)
 
 try:
-    dom = conn.lookupByName(name)
+    dom = conn.lookupByName(args.domain)
     # Annoyiingly, libvirt prints its own error message here
 except libvirt.libvirtError:
-    print("Domain %s is not running" % name)
-    sys.exit(0)
+    print("Domain %s is not running" % args.domain)
+    exit(0)
 
 info = dom.info()
 print_section("Domain info")
@@ -68,7 +68,7 @@ print_section("Devices")
 devs = ctx.xpathEval("/domain/devices/*")
 for d in devs:
     ctx.setContextNode(d)
-    #pdb.set_trace()
+    # import pdb; pdb.set_trace()
     type = print_xml("Type:", ctx, "@type")
     if type == "file":
         print_xml("Source:", ctx, "source/@file")
