@@ -3,15 +3,13 @@
 import sys
 import lxml
 import lxml.etree
-import string
+from typing import Dict, List, Set, Tuple  # noqa F401
 
 if len(sys.argv) >= 2:
     # Munge import path to insert build location for libvirt mod
     sys.path.insert(0, sys.argv[1])
 import libvirt
 
-if sys.version > '3':
-    long = int
 
 def get_libvirt_api_xml_path():
     import subprocess
@@ -22,6 +20,7 @@ def get_libvirt_api_xml_path():
         sys.exit(proc.returncode)
     return stdout.splitlines()[0]
 
+
 # Path to the libvirt API XML file
 if len(sys.argv) >= 3:
     xml = sys.argv[2]
@@ -34,18 +33,15 @@ with open(xml, "r") as fp:
 verbose = False
 fail = False
 
-enumvals = {}
-second_pass = []
-wantenums = []
-wantfunctions = []
+enumvals = {}  # type: Dict[str, Dict[str, int]]
+second_pass = []  # type: List[str]
+wantenums = []  # type: List[str]
+wantfunctions = []  # type: List[str]
 
 # Phase 1: Identify all functions and enums in public API
-set = tree.xpath('/api/files/file/exports[@type="function"]/@symbol')
-for n in set:
-    wantfunctions.append(n)
+wantfunctions = tree.xpath('/api/files/file/exports[@type="function"]/@symbol')
 
-set = tree.xpath('/api/symbols/enum')
-for n in set:
+for n in tree.xpath('/api/symbols/enum'):
     typ = n.attrib['type']
     name = n.attrib['name']
     val = n.attrib['value']
@@ -76,43 +72,42 @@ for n in second_pass:
     # Version 4.0.0 was broken as missing VIR_TYPED_PARAM enums
     # constants. This is harmless from POV of validating API
     # coverage so ignore this error.
-    if (type(val) != int and
+    if (not isinstance(val, int) and
         not val.startswith("VIR_TYPED_PARAM_")):
         fail = True
         print("Cannot get a value of enum %s (originally %s)" % (val, name))
     enumvals[typ][name] = val
 
-set = tree.xpath('/api/files/file/exports[@type="enum"]/@symbol')
-for n in set:
+for n in tree.xpath('/api/files/file/exports[@type="enum"]/@symbol'):
     for enumval in enumvals.values():
         if n in enumval:
-            enum = enumval
+            enumv = enumval
             break
     # Eliminate sentinels
-    if n.endswith('_LAST') and enum[n] == max(enum.values()):
+    if n.endswith('_LAST') and enumv[n] == max(enumv.values()):
         continue
     wantenums.append(n)
 
 # Phase 2: Identify all classes and methods in the 'libvirt' python module
-gotenums = []
-gottypes = []
-gotfunctions = { "libvirt": [] }
+gotenums = []  # type: List[str]
+gottypes = []  # type: List[str]
+gotfunctions = {"libvirt": []}  # type: Dict[str, List[str]]
 
 for name in dir(libvirt):
-    if name[0] == '_':
+    if name.startswith('_'):
         continue
     thing = getattr(libvirt, name)
     # Special-case libvirtError to deal with python 2.4 difference
     # in Exception class type reporting.
-    if type(thing) in (int, long):
+    if isinstance(thing, int):
         gotenums.append(name)
+    elif getattr(thing, "__module__", "") == "typing":
+        continue
     elif type(thing) == type or name == "libvirtError":
         gottypes.append(name)
         gotfunctions[name] = []
     elif callable(thing):
         gotfunctions["libvirt"].append(name)
-    else:
-       pass
 
 for enum in wantenums:
     if enum not in gotenums:
@@ -124,19 +119,17 @@ for enum in wantenums:
 for klassname in gottypes:
     klassobj = getattr(libvirt, klassname)
     for name in dir(klassobj):
-        if name[0] == '_':
+        if name.startswith('_'):
             continue
         if name == 'c_pointer':
             continue
         thing = getattr(klassobj, name)
         if callable(thing):
             gotfunctions[klassname].append(name)
-        else:
-            pass
 
 
 # Phase 3: First cut at mapping of C APIs to python classes + methods
-basicklassmap = {}
+basicklassmap = {}  # type: Dict[str, Tuple[str, str, str]]
 
 for cname in wantfunctions:
     name = cname
@@ -188,12 +181,11 @@ for cname in wantfunctions:
         name.endswith("Callback")):
         continue
 
-
     # virEvent APIs go into main 'libvirt' namespace not any class
     if name[0:8] == "virEvent":
         if name[-4:] == "Func":
             continue
-        basicklassmap[name] = ["libvirt", name, cname]
+        basicklassmap[name] = ("libvirt", name, cname)
     else:
         found = False
         # To start with map APIs to classes based on the
@@ -204,24 +196,20 @@ for cname in wantfunctions:
             if name[0:klen] == klassname:
                 found = True
                 if name not in basicklassmap:
-                    basicklassmap[name] = [klassname, name[klen:], cname]
+                    basicklassmap[name] = (klassname, name[klen:], cname)
                 elif len(basicklassmap[name]) < klen:
-                    basicklassmap[name] = [klassname, name[klen:], cname]
+                    basicklassmap[name] = (klassname, name[klen:], cname)
 
         # Anything which can't map to a class goes into the
         # global namespaces
         if not found:
-            basicklassmap[name] = ["libvirt", name[3:], cname]
+            basicklassmap[name] = ("libvirt", name[3:], cname)
 
 
 # Phase 4: Deal with oh so many special cases in C -> python mapping
-finalklassmap = {}
-
-for name in sorted(basicklassmap):
-    klass = basicklassmap[name][0]
-    func = basicklassmap[name][1]
-    cname = basicklassmap[name][2]
+finalklassmap = {}  # type: Dict[str, Tuple[str, str, str]]
 
+for name, (klass, func, cname) in sorted(basicklassmap.items()):
     # The object lifecycle APIs are irrelevant since they're
     # used inside the object constructors/destructors.
     if func in ["Ref", "Free", "New", "GetConnect", "GetDomain", "GetNetwork"]:
@@ -231,7 +219,6 @@ for name in sorted(basicklassmap):
         else:
             continue
 
-
     # All the error handling methods need special handling
     if klass == "libvirt":
         if func in ["CopyLastError", "DefaultErrorFunc",
@@ -264,7 +251,7 @@ for name in sorted(basicklassmap):
                 "LookupByUUIDString", "LookupByVolume" "LookupByName",
                 "LookupByID", "LookupByName", "LookupByKey", "LookupByPath",
                 "LookupByMACString", "LookupByUsage", "LookupByVolume",
-                "LookupByTargetPath","LookupSCSIHostByWWN", "LookupByPortDev",
+                "LookupByTargetPath", "LookupSCSIHostByWWN", "LookupByPortDev",
                 "Restore", "RestoreFlags",
                 "SaveImageDefineXML", "SaveImageGetXMLDesc", "DefineXMLFlags"]:
         if klass != "virDomain":
@@ -336,17 +323,14 @@ for name in sorted(basicklassmap):
     if func == "mACString":
         func = "MACString"
 
-    finalklassmap[name] = [klass, func, cname]
+    finalklassmap[name] = (klass, func, cname)
 
 
 # Phase 5: Validate sure that every C API is mapped to a python API
-usedfunctions = {}
-for name in sorted(finalklassmap):
-    klass = finalklassmap[name][0]
-    func = finalklassmap[name][1]
-
+usedfunctions = set()  # type: Set[str]
+for name, (klass, func, cname) in sorted(finalklassmap.items()):
     if func in gotfunctions[klass]:
-        usedfunctions["%s.%s" % (klass, func)] = 1
+        usedfunctions.add("%s.%s" % (klass, func))
         if verbose:
             print("PASS %s -> %s.%s" % (name, klass, func))
     else:
@@ -366,7 +350,7 @@ for klass in gotfunctions:
             continue
 
         key = "%s.%s" % (klass, func)
-        if not key in usedfunctions:
+        if key not in usedfunctions:
             print("FAIL %s.%s       (Python API not mapped to C)" % (klass, func))
             fail = True
         else:
@@ -374,9 +358,7 @@ for klass in gotfunctions:
                 print("PASS %s.%s" % (klass, func))
 
 # Phase 7: Validate that all the low level C APIs have binding
-for name in sorted(finalklassmap):
-    cname = finalklassmap[name][2]
-
+for name, (klass, func, cname) in sorted(finalklassmap.items()):
     pyname = cname
     if pyname == "virSetErrorFunc":
         pyname = "virRegisterErrorHandler"
@@ -386,7 +368,7 @@ for name in sorted(finalklassmap):
     # These exist in C and exist in python, but we've got
     # a pure-python impl so don't check them
     if name in ["virStreamRecvAll", "virStreamSendAll",
-            "virStreamSparseRecvAll", "virStreamSparseSendAll"]:
+                "virStreamSparseRecvAll", "virStreamSparseSendAll"]:
         continue
 
     try:
