@@ -17,3 +17,9 @@ class TestLibvirtDomain(unittest.TestCase):
         self.assertTrue("weight" in params)
         params["weight"] = 100
         self.dom.setSchedulerParameters(params)
+
+    @unittest.skipIf(libvirt.getVersion() == 4000000,
+                     "test driver screenshot broken in 4.0.0")
+    def testScreenshot(self):
+        stream = self.conn.newStream()
+        ss = self.dom.screenshot(stream, 0, 0)
